==> haskell-filestore-0.6.5-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-filestore.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 filestore
version:              0.6.5
visibility:           public
id:                   filestore-0.6.5-7kmZI0S28TT4OZQAIKeeHM
key:                  filestore-0.6.5-7kmZI0S28TT4OZQAIKeeHM
license:              BSD-3-Clause
maintainer:           jgm@berkeley.edu
author:               John MacFarlane, Gwern Branwen, Sebastiaan Visser
stability:            Experimental
synopsis:             Interface for versioning file stores.
description:
    The filestore library provides an abstract interface for a versioning
    file store, and modules that instantiate this interface.  Currently
    Git, Darcs, and Mercurial modules are provided, and other VCSs
    or databases could be added.

category:             Data
abi:                  956d61789c129e4fc923e3bbfa46d0d5
exposed:              True
exposed-modules:
    Data.FileStore Data.FileStore.Darcs Data.FileStore.Generic
    Data.FileStore.Git Data.FileStore.Mercurial Data.FileStore.Types
    Data.FileStore.Utils

hidden-modules:
    Data.FileStore.DarcsXml Data.FileStore.MercurialCommandServer
    Data.FileStore.Compat.Locale

import-dirs:          /usr/lib/ghc-9.0.2/site-local/filestore-0.6.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/filestore-0.6.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-filestore
hs-libraries:         HSfilestore-0.6.5-7kmZI0S28TT4OZQAIKeeHM
depends:
    Diff-0.4.1-7CbxTxD7TZALFiHX02rp6g base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1 directory-1.3.6.2
    filepath-1.4.2.1 old-locale-1.0.0.7-B94o3sNLYrV8oE3WO2rqHh
    parsec-3.1.14.0 process-1.6.13.2
    split-0.2.3.5-JTiCyTdGupA4yWu7SHDWhG time-1.9.3
    utf8-string-1.0.2-9eFA57BgKXNHtjvfuIOq9f
    xml-1.3.14-6hlhhPBptprHwK7nsE7OzM

haddock-interfaces:   /usr/share/doc/haskell-filestore/html/filestore.haddock
haddock-html:         /usr/share/doc/haskell-filestore/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-filestore-0.6.5-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-filestore.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 filestore
version:              0.6.5
visibility:           public
id:                   filestore-0.6.5-8cHWbQKSl1RG8HsrGrtaxx
key:                  filestore-0.6.5-8cHWbQKSl1RG8HsrGrtaxx
license:              BSD-3-Clause
maintainer:           jgm@berkeley.edu
author:               John MacFarlane, Gwern Branwen, Sebastiaan Visser
stability:            Experimental
synopsis:             Interface for versioning file stores.
description:
    The filestore library provides an abstract interface for a versioning
    file store, and modules that instantiate this interface.  Currently
    Git, Darcs, and Mercurial modules are provided, and other VCSs
    or databases could be added.

category:             Data
abi:                  04a9e8d7eac84c5da635dd6814f947db
exposed:              True
exposed-modules:
    Data.FileStore Data.FileStore.Darcs Data.FileStore.Generic
    Data.FileStore.Git Data.FileStore.Mercurial Data.FileStore.Types
    Data.FileStore.Utils

hidden-modules:
    Data.FileStore.DarcsXml Data.FileStore.MercurialCommandServer
    Data.FileStore.Compat.Locale

import-dirs:          /usr/lib/ghc-9.0.2/site-local/filestore-0.6.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/filestore-0.6.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-filestore
hs-libraries:         HSfilestore-0.6.5-8cHWbQKSl1RG8HsrGrtaxx
depends:
    Diff-0.4.1-GxxeqJuHncl87iJRFTZxdi base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1 directory-1.3.6.2
    filepath-1.4.2.1 old-locale-1.0.0.7-B94o3sNLYrV8oE3WO2rqHh
    parsec-3.1.14.0 process-1.6.13.2
    split-0.2.3.5-LKOrts4ugNs7HOmB371KGw time-1.9.3
    utf8-string-1.0.2-9eFA57BgKXNHtjvfuIOq9f
    xml-1.3.14-6hlhhPBptprHwK7nsE7OzM

haddock-interfaces:   /usr/share/doc/haskell-filestore/html/filestore.haddock
haddock-html:         /usr/share/doc/haskell-filestore/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
